@@ -12,8 +12,7 @@ class SedaroApiException(ApiException, SedaroException):
     Base exception for api exceptions raised by the Sedaro Python Client, inherits from `sedaro_base_client`'s
     `ApiException`
     """
-
-    def __init__(self, status: Union[str, int, None] = None, reason: Union[str, None] = None, api_response: Any = None):
+    def __init__(status: Union[str, int, None] = None, reason: Union[str, None] = None, api_response: Any = None):
         """Initialize SedaroApiException
 
         Args:
@@ -21,7 +20,8 @@ class SedaroApiException(ApiException, SedaroException):
             reason (Union[str, None], optional): Defaults to None.
             api_response (Any, optional): Defaults to None.
         """
-        super().__init__(status=status, reason=reason, api_response=api_response)
+        super.__init__(status=status, reason=reason, api_response=api_response)
+    pass
 
 
 class NonexistantBlockError(SedaroException):
@@ -30,7 +30,3 @@ class NonexistantBlockError(SedaroException):
 
 class NoBlockFoundError(SedaroException):
     pass
-
-
-class NoSimResultsError(SedaroApiException):
-    pass
